@@ -13,3 +13,6 @@
 # limitations under the License.
 #
 from .scheduler import EventScheduler
+from .utils import create_echo_function
+
+__all__ = [EventScheduler, create_echo_function]
