@@ -12,7 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from unittest.mock import Mock
+
 from mycroft_bus_client import MessageBusClient
+from mycroft_bus_client.client import MessageWaiter
+
 
 WS_CONF = {
     'websocket': {
@@ -34,3 +38,22 @@ class TestMessageBusClient:
     def test_create_client(self):
         mc = MessageBusClient()
         assert mc.client.url == 'ws://0.0.0.0:8181/core'
+
+
+class TestMessageWaiter:
+    def test_message_wait_success(self):
+        bus = Mock()
+        waiter = MessageWaiter(bus, 'delayed.message')
+        bus.once.assert_called_with('delayed.message', waiter._handler)
+
+        test_msg = Mock(name='test_msg')
+        waiter._handler(test_msg)  # Inject response
+
+        assert waiter.wait() == test_msg
+
+    def test_message_wait_timeout(self):
+        bus = Mock()
+        waiter = MessageWaiter(bus, 'delayed.message')
+        bus.once.assert_called_with('delayed.message', waiter._handler)
+
+        assert waiter.wait(0.3) is None
